"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var fs_1 = __importDefault(require("fs"));
var glob_1 = __importDefault(require("glob"));
var prettier_1 = __importDefault(require("prettier"));
var ttp = __importStar(require("../src"));
var prettierConfig = prettier_1.default.resolveConfig.sync(path_1.default.join(__dirname, '../.prettierrc'));
var testCases = glob_1.default.sync('**/input.{d.ts,ts,tsx}', { absolute: true, cwd: __dirname });
// Create program for all files to speed up tests
var program = ttp.createProgram(testCases, ttp.loadConfig(path_1.default.resolve(__dirname, '../tsconfig.json')));
var _loop_1 = function (testCase) {
    var dirname = path_1.default.dirname(testCase);
    var testName = dirname.substr(__dirname.length + 1);
    var astPath = path_1.default.join(dirname, 'output.json');
    var outputPath = path_1.default.join(dirname, 'output.js');
    it(testName, function () {
        var ast = ttp.parseFromProgram(testCase, program);
        //#region Check AST matches
        if (fs_1.default.existsSync(astPath)) {
            expect(ast).toMatchObject(JSON.parse(fs_1.default.readFileSync(astPath, 'utf8')));
        }
        else {
            fs_1.default.writeFileSync(astPath, prettier_1.default.format(JSON.stringify(ast), __assign({}, prettierConfig, { filepath: astPath })));
        }
        //#endregion
        var result = '';
        // For d.ts files we just generate the AST
        if (testCase.endsWith('.d.ts')) {
            result = ttp.generate(ast);
        }
        // For .tsx? files we transpile them and inject the proptypes
        else {
            var transpiled = ttp.ts.transpileModule(fs_1.default.readFileSync(testCase, 'utf8'), {
                compilerOptions: {
                    target: ttp.ts.ScriptTarget.ESNext,
                    jsx: ttp.ts.JsxEmit.Preserve,
                },
            }).outputText;
            var injected = ttp.inject(ast, transpiled);
            if (!injected) {
                throw new Error('Injection failed');
            }
            result = injected;
        }
        //#region Check generated and/or injected proptypes
        var propTypes = prettier_1.default.format(result, __assign({}, prettierConfig, { filepath: outputPath }));
        if (fs_1.default.existsSync(outputPath)) {
            expect(propTypes.replace(/\r?\n/, '\n')).toMatch(fs_1.default.readFileSync(outputPath, 'utf8').replace(/\r?\n/, '\n'));
        }
        else {
            fs_1.default.writeFileSync(outputPath, propTypes);
        }
        //#endregion
    });
};
for (var _i = 0, testCases_1 = testCases; _i < testCases_1.length; _i++) {
    var testCase = testCases_1[_i];
    _loop_1(testCase);
}
//# sourceMappingURL=index.test.js.map